package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.RegisterSchoolFileMapper;
import com.ruoyi.system.domain.RegisterSchoolFile;
import com.ruoyi.system.service.IRegisterSchoolFileService;

/**
 * 注册-学校-附件Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
@Service
public class RegisterSchoolFileServiceImpl implements IRegisterSchoolFileService 
{
    @Autowired
    private RegisterSchoolFileMapper registerSchoolFileMapper;

    /**
     * 查询注册-学校-附件
     * 
     * @param id 注册-学校-附件主键
     * @return 注册-学校-附件
     */
    @Override
    public RegisterSchoolFile selectRegisterSchoolFileById(Long id)
    {
        return registerSchoolFileMapper.selectRegisterSchoolFileById(id);
    }

    /**
     * 查询注册-学校-附件列表
     * 
     * @param registerSchoolFile 注册-学校-附件
     * @return 注册-学校-附件
     */
    @Override
    public List<RegisterSchoolFile> selectRegisterSchoolFileList(RegisterSchoolFile registerSchoolFile)
    {
        return registerSchoolFileMapper.selectRegisterSchoolFileList(registerSchoolFile);
    }

    /**
     * 新增注册-学校-附件
     * 
     * @param registerSchoolFile 注册-学校-附件
     * @return 结果
     */
    @Override
    public int insertRegisterSchoolFile(RegisterSchoolFile registerSchoolFile)
    {
        return registerSchoolFileMapper.insertRegisterSchoolFile(registerSchoolFile);
    }

    /**
     * 修改注册-学校-附件
     * 
     * @param registerSchoolFile 注册-学校-附件
     * @return 结果
     */
    @Override
    public int updateRegisterSchoolFile(RegisterSchoolFile registerSchoolFile)
    {
        return registerSchoolFileMapper.updateRegisterSchoolFile(registerSchoolFile);
    }

    /**
     * 批量删除注册-学校-附件
     * 
     * @param ids 需要删除的注册-学校-附件主键
     * @return 结果
     */
    @Override
    public int deleteRegisterSchoolFileByIds(Long[] ids)
    {
        return registerSchoolFileMapper.deleteRegisterSchoolFileByIds(ids);
    }

    /**
     * 删除注册-学校-附件信息
     * 
     * @param id 注册-学校-附件主键
     * @return 结果
     */
    @Override
    public int deleteRegisterSchoolFileById(Long id)
    {
        return registerSchoolFileMapper.deleteRegisterSchoolFileById(id);
    }
}
