package com.ruoyi.web.controller.register;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.RegisterSchoolFile;
import com.ruoyi.system.service.IRegisterSchoolFileService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 注册-学校-附件Controller
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
@RestController
@RequestMapping("/register/file")
public class RegisterSchoolFileController extends BaseController
{
    @Autowired
    private IRegisterSchoolFileService registerSchoolFileService;

    /**
     * 查询注册-学校-附件列表
     */
    @PreAuthorize("@ss.hasPermi('register:file:list')")
    @GetMapping("/list")
    public TableDataInfo list(RegisterSchoolFile registerSchoolFile)
    {
        startPage();
        List<RegisterSchoolFile> list = registerSchoolFileService.selectRegisterSchoolFileList(registerSchoolFile);
        return getDataTable(list);
    }

    /**
     * 导出注册-学校-附件列表
     */
    @PreAuthorize("@ss.hasPermi('register:file:export')")
    @Log(title = "注册-学校-附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RegisterSchoolFile registerSchoolFile)
    {
        List<RegisterSchoolFile> list = registerSchoolFileService.selectRegisterSchoolFileList(registerSchoolFile);
        ExcelUtil<RegisterSchoolFile> util = new ExcelUtil<RegisterSchoolFile>(RegisterSchoolFile.class);
        util.exportExcel(response, list, "注册-学校-附件数据");
    }

    /**
     * 获取注册-学校-附件详细信息
     */
    @PreAuthorize("@ss.hasPermi('register:file:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(registerSchoolFileService.selectRegisterSchoolFileById(id));
    }

    /**
     * 新增注册-学校-附件
     */
    @PreAuthorize("@ss.hasPermi('register:file:add')")
    @Log(title = "注册-学校-附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RegisterSchoolFile registerSchoolFile)
    {
        return toAjax(registerSchoolFileService.insertRegisterSchoolFile(registerSchoolFile));
    }

    /**
     * 修改注册-学校-附件
     */
    @PreAuthorize("@ss.hasPermi('register:file:edit')")
    @Log(title = "注册-学校-附件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RegisterSchoolFile registerSchoolFile)
    {
        return toAjax(registerSchoolFileService.updateRegisterSchoolFile(registerSchoolFile));
    }

    /**
     * 删除注册-学校-附件
     */
    @PreAuthorize("@ss.hasPermi('register:file:remove')")
    @Log(title = "注册-学校-附件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(registerSchoolFileService.deleteRegisterSchoolFileByIds(ids));
    }
}
